@@ -1,6 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from functools import partial
-
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose
@@ -12,6 +10,8 @@ from astropy.tests.helper import assert_quantity_allclose
 
 from .. import coordinate_frames as cf
 
+import astropy
+astropy_version = astropy.__version__
 
 coord_frames = coord.builtin_frames.__all__[:]
 
@@ -29,9 +29,15 @@ focal = cf.Frame2D(name='focal', axes_order=(0, 1), unit=(u.m, u.m))
 
 spec1 = cf.SpectralFrame(name='freq', unit=[u.Hz, ], axes_order=(2, ))
 spec2 = cf.SpectralFrame(name='wave', unit=[u.m, ], axes_order=(2, ), axes_names=('lambda', ))
+spec3 = cf.SpectralFrame(name='energy', unit=[u.J, ], axes_order=(2, ))
+spec4 = cf.SpectralFrame(name='pixel', unit=[u.pix, ], axes_order=(2, ))
+spec5 = cf.SpectralFrame(name='speed', unit=[u.m/u.s, ], axes_order=(2, ))
 
 comp1 = cf.CompositeFrame([icrs, spec1])
 comp2 = cf.CompositeFrame([focal, spec2])
+comp3 = cf.CompositeFrame([icrs, spec3])
+comp4 = cf.CompositeFrame([icrs, spec4])
+comp5 = cf.CompositeFrame([icrs, spec5])
 comp = cf.CompositeFrame([comp1, cf.SpectralFrame(axes_order=(3,), unit=(u.m,))])
 
 xscalar = 1
@@ -47,6 +53,9 @@ inputs3 = [(xscalar, yscalar, xscalar), (xarr, yarr, xarr)]
 def test_units():
     assert(comp1.unit == (u.deg, u.deg, u.Hz))
     assert(comp2.unit == (u.m, u.m, u.m))
+    assert(comp3.unit == (u.deg, u.deg, u.J))
+    assert(comp4.unit == (u.deg, u.deg, u.pix))
+    assert(comp5.unit == (u.deg, u.deg, u.m/u.s))
     assert(comp.unit == (u.deg, u.deg, u.Hz, u.m))
 
 
@@ -131,7 +140,7 @@ def test_base_coordinate():
 
 
 def test_temporal_relative():
-    t = cf.TemporalFrame(reference_time=Time("2018-01-01T00:00:00"), unit=u.s)
+    t = cf.TemporalFrame(reference_frame=Time("2018-01-01T00:00:00"), unit=u.s)
     assert t.coordinates(10) == Time("2018-01-01T00:00:00") + 10 * u.s
     assert t.coordinates(10 * u.s) == Time("2018-01-01T00:00:00") + 10 * u.s
 
@@ -139,7 +148,7 @@ def test_temporal_relative():
     assert a[0] == Time("2018-01-01T00:00:00") + 10 * u.s
     assert a[1] == Time("2018-01-01T00:00:00") + 20 * u.s
 
-    t = cf.TemporalFrame(reference_time=Time("2018-01-01T00:00:00"))
+    t = cf.TemporalFrame(reference_frame=Time("2018-01-01T00:00:00"))
     assert t.coordinates(10 * u.s) == Time("2018-01-01T00:00:00") + 10 * u.s
 
     a = t.coordinates((10, 20) * u.s)
@@ -147,15 +156,16 @@ def test_temporal_relative():
     assert a[1] == Time("2018-01-01T00:00:00") + 20 * u.s
 
 
+@pytest.mark.skipif(astropy_version<"4", reason="Requires astropy 4.0 or higher")
 def test_temporal_absolute():
-    t = cf.TemporalFrame()
+    t = cf.TemporalFrame(reference_frame=Time([], format='isot'))
     assert t.coordinates("2018-01-01T00:00:00") == Time("2018-01-01T00:00:00")
 
     a = t.coordinates(("2018-01-01T00:00:00", "2018-01-01T00:10:00"))
     assert a[0] == Time("2018-01-01T00:00:00")
     assert a[1] == Time("2018-01-01T00:10:00")
 
-    t = cf.TemporalFrame(reference_frame=partial(Time, scale='tai'))
+    t = cf.TemporalFrame(reference_frame=Time([], scale='tai', format='isot'))
     assert t.coordinates("2018-01-01T00:00:00") == Time("2018-01-01T00:00:00", scale='tai')
 
 
@@ -180,7 +190,7 @@ def test_coordinate_to_quantity_celestial(inp):
     with pytest.raises(ValueError):
         cel.coordinate_to_quantity((1, 2))
 
-        
+
 @pytest.mark.parametrize('inp', [
     (100,),
     (100 * u.nm,),
@@ -196,14 +206,15 @@ def test_coordinate_to_quantity_spectral(inp):
     (Time("2011-01-01T00:00:10"),),
     (10 * u.s,)
 ])
+@pytest.mark.skipif(astropy_version<"4", reason="Requires astropy 4.0 or higher.")
 def test_coordinate_to_quantity_temporal(inp):
-    temp = cf.TemporalFrame(reference_time=Time("2011-01-01T00:00:00"), unit=u.s)
+    temp = cf.TemporalFrame(reference_frame=Time("2011-01-01T00:00:00"), unit=u.s)
 
     t = temp.coordinate_to_quantity(*inp)
 
     assert_quantity_allclose(t, 10 * u.s)
 
-    temp2 = cf.TemporalFrame(unit=u.s)
+    temp2 = cf.TemporalFrame(reference_frame=Time([], format='isot'), unit=u.s)
 
     tt = Time("2011-01-01T00:00:00")
     t = temp2.coordinate_to_quantity(tt)
@@ -222,7 +233,7 @@ def test_coordinate_to_quantity_composite(inp):
     # Composite
     wave_frame = cf.SpectralFrame(axes_order=(0, ), unit=u.AA)
     time_frame = cf.TemporalFrame(
-        axes_order=(1, ), unit=u.s, reference_time=Time("2011-01-01T00:00:00"))
+        axes_order=(1, ), unit=u.s, reference_frame=Time("2011-01-01T00:00:00"))
     sky_frame = cf.CelestialFrame(axes_order=(2, 3), reference_frame=coord.ICRS())
 
     comp = cf.CompositeFrame([wave_frame, time_frame, sky_frame])
@@ -239,7 +250,7 @@ def test_stokes_frame():
 
     assert sf.coordinates(0) == 'I'
     assert sf.coordinates(0 * u.pix) == 'I'
-    assert sf.coordinate_to_quantity('I') == 0 * u.pix
+    assert sf.coordinate_to_quantity('I') == 0 * u.one
     assert sf.coordinate_to_quantity(0) == 0
 
 
@@ -252,7 +263,7 @@ def test_stokes_frame():
 def test_coordinate_to_quantity_frame2d_composite(inp):
     wave_frame = cf.SpectralFrame(axes_order=(0, ), unit=u.AA)
     time_frame = cf.TemporalFrame(
-        axes_order=(1, ), unit=u.s, reference_time=Time("2011-01-01T00:00:00"))
+        axes_order=(1, ), unit=u.s, reference_frame=Time("2011-01-01T00:00:00"))
 
     frame2d = cf.Frame2D(name="intermediate", axes_order=(2, 3), unit=(u.one, u.one))
 
@@ -280,6 +291,7 @@ def test_coordinate_to_quantity_frame_2d():
         assert_quantity_allclose(output, exp)
 
 
+@pytest.mark.skipif(astropy_version<"4", reason="Requires astropy 4.0 or higher.")
 def test_coordinate_to_quantity_error():
     frame = cf.Frame2D(unit=(u.one, u.arcsec))
     with pytest.raises(ValueError):
@@ -288,24 +300,28 @@ def test_coordinate_to_quantity_error():
     with pytest.raises(ValueError):
         comp1.coordinate_to_quantity((1, 1), 2)
 
-    frame = cf.TemporalFrame(unit=u.s)
+    frame = cf.TemporalFrame(reference_frame=Time([], format='isot'), unit=u.s)
     with pytest.raises(ValueError):
         frame.coordinate_to_quantity(1)
-    
+
 
 def test_axis_physical_type():
     assert icrs.axis_physical_types == ("pos.eq.ra", "pos.eq.dec")
     assert spec1.axis_physical_types == ("em.freq",)
     assert spec2.axis_physical_types == ("em.wl",)
+    assert spec3.axis_physical_types == ("em.energy",)
+    assert spec4.axis_physical_types == ("custom:unknown",)
+    assert spec5.axis_physical_types == ("spect.dopplerVeloc",)
     assert comp1.axis_physical_types == ("pos.eq.ra", "pos.eq.dec", "em.freq")
     assert comp2.axis_physical_types == ("custom:x", "custom:y", "em.wl")
+    assert comp3.axis_physical_types == ("pos.eq.ra", "pos.eq.dec", "em.energy")
     assert comp.axis_physical_types == ('pos.eq.ra', 'pos.eq.dec', 'em.freq', 'em.wl')
 
-    spec3 = cf.SpectralFrame(name='waven', axes_order=(1,),
+    spec6 = cf.SpectralFrame(name='waven', axes_order=(1,),
                              axis_physical_types='em.wavenumber')
-    assert spec3.axis_physical_types == ('em.wavenumber',)
+    assert spec6.axis_physical_types == ('em.wavenumber',)
 
-    t = cf.TemporalFrame(reference_time=Time("2018-01-01T00:00:00"), unit=u.s)
+    t = cf.TemporalFrame(reference_frame=Time("2018-01-01T00:00:00"), unit=u.s)
     assert t.axis_physical_types == ('time',)
 
     fr2d = cf.Frame2D(name='d', axes_names=("x", "y"))
@@ -322,16 +338,22 @@ def test_axis_physical_type():
 
     fr = cf.CelestialFrame(reference_frame=coord.ICRS(), axis_physical_types=("ra", "dec"))
     assert fr.axis_physical_types == ("custom:ra", "custom:dec")
-    
+
     fr = cf.CelestialFrame(reference_frame=coord.BarycentricTrueEcliptic())
     assert fr.axis_physical_types == ('pos.ecliptic.lon', 'pos.ecliptic.lat')
 
-    frame = cf.CoordinateFrame(name='custom_frame', axes_type=("SPATIAL",), axes_order=(0,), axis_physical_types="length", axes_names="x", naxes=1)
+    frame = cf.CoordinateFrame(name='custom_frame', axes_type=("SPATIAL",),
+                               axes_order=(0,), axis_physical_types="length",
+                               axes_names="x", naxes=1)
     assert frame.axis_physical_types == ("custom:length",)
-    frame = cf.CoordinateFrame(name='custom_frame', axes_type=("SPATIAL",), axes_order=(0,), axis_physical_types=("length",), axes_names="x", naxes=1)
+    frame = cf.CoordinateFrame(name='custom_frame', axes_type=("SPATIAL",),
+                               axes_order=(0,), axis_physical_types=("length",),
+                               axes_names="x", naxes=1)
     assert frame.axis_physical_types == ("custom:length",)
     with pytest.raises(ValueError):
-        cf.CoordinateFrame(name='custom_frame', axes_type=("SPATIAL",), axes_order=(0,), axis_physical_types=("length", "length"), naxes=1)
+        cf.CoordinateFrame(name='custom_frame', axes_type=("SPATIAL",),
+                           axes_order=(0,),
+                           axis_physical_types=("length", "length"), naxes=1)
 
 
 def test_base_frame():
