@@ -20,7 +20,7 @@ sky_pairs = {"equatorial": ["RA", "DEC"],
              "helioecliptic": ["HLON", "HLAT"],
              "supergalactic": ["SLON", "SLAT"],
              # "spec": specsystems
-             }
+            }
 
 radesys = ['ICRS', 'FK5', 'FK4', 'FK4-NO-E', 'GAPPT', 'GALACTIC']
 
@@ -72,7 +72,7 @@ def _toindex(value):
     return indx
 
 
-def get_values(units=None, *args):
+def get_values(units, *args):
     """
     Return the values of Quantity objects after optionally converting to units.
 
@@ -85,9 +85,10 @@ def get_values(units=None, *args):
         Quantity inputs.
     """
     if units is not None:
-        return [a.to_value(unit) for a, unit in zip(args, units)]
+        result = [a.to_value(unit) for a, unit in zip(args, units)]
     else:
-        return [a.value for a in args]
+        result = [a.value for a in args]
+    return result
 
 
 def _compute_lon_pole(skycoord, projection):
@@ -294,7 +295,7 @@ sky_systems_map = {'ICRS': coords.ICRS,
                    'FK4NOE': coords.FK4NoETerms,
                    'GAL': coords.Galactic,
                    'HOR': coords.AltAz
-                   }
+                  }
 
 
 def make_fitswcs_transform(header):
@@ -423,8 +424,7 @@ def fitswcs_nonlinear(header):
         transforms.append(n2c)
     if transforms:
         return functools.reduce(core._model_oper('|'), transforms)
-    else:
-        return None
+    return None
 
 
 def create_projection_transform(projcode):
@@ -456,13 +456,13 @@ def isnumerical(val):
     """
     Determine if a value is numerical (number or np.array of numbers).
     """
-    dtypes = ['uint64', 'float64', 'int8', 'int64', 'int16', 'uint16', 'uint8',
-              'float32', 'int32', 'uint32']
     isnum = True
     if isinstance(val, coords.SkyCoord):
         isnum = False
     elif isinstance(val, u.Quantity):
         isnum = False
-    elif isinstance(val, np.ndarray) and val.dtype not in dtypes:
+    elif (isinstance(val, np.ndarray)
+          and not np.issubdtype(val.dtype, np.floating)
+          and not np.issubdtype(val.dtype, np.integer)):
         isnum = False
     return isnum
