@@ -2,7 +2,7 @@
 import functools
 import itertools
 import numpy as np
-from astropy.modeling.core import Model
+from astropy.modeling.core import Model # , fix_inputs
 from astropy.modeling import utils as mutils
 
 from .api import GWCSAPIMixin
@@ -12,6 +12,14 @@ from .utils import _toindex
 from . import utils
 
 
+HAS_FIX_INPUTS = True
+
+try:
+    from astropy.modeling.core import fix_inputs
+except ImportError:
+    HAS_FIX_INPUTS = False
+
+
 __all__ = ['WCS']
 
 
@@ -43,6 +51,7 @@ class WCS(GWCSAPIMixin):
         self._name = name
         self._array_shape = None
         self._initialize_wcs(forward_transform, input_frame, output_frame)
+        self._pixel_shape = None
 
     def _initialize_wcs(self, forward_transform, input_frame, output_frame):
         if forward_transform is not None:
@@ -188,7 +197,7 @@ class WCS(GWCSAPIMixin):
             frame = frame.name
         frame_names = [getattr(item[0], "name", item[0]) for item in self._pipeline]
         return frame_names.index(frame)
-        
+
     def _get_frame_name(self, frame):
         """
         Return the name of the frame and a ``CoordinateFrame`` object.
@@ -283,7 +292,9 @@ class WCS(GWCSAPIMixin):
         """
         if not utils.isnumerical(args[0]):
             args = self.output_frame.coordinate_to_quantity(*args)
-            if not self.forward_transform.uses_quantity:
+            if self.output_frame.naxes == 1:
+                args = [args]
+            if not self.backward_transform.uses_quantity:
                 args = utils.get_values(self.output_frame.unit, *args)
 
         with_units = kwargs.pop('with_units', False)
@@ -591,3 +602,35 @@ class WCS(GWCSAPIMixin):
                 result = np.squeeze(result)
 
         return result.T
+
+    def fix_inputs(self, fixed):
+        """
+        Return a new unique WCS by fixing inputs to constant values.
+
+        Parameters
+        ----------
+        fixed : dict
+            Keyword arguments with fixed values corresponding to `self.selector`.
+
+        Returns
+        -------
+        new_wcs : `WCS`
+            A new unique WCS corresponding to the values in `fixed`.
+
+        Examples
+        --------
+        >>> w = WCS(pipeline, selector={"spectral_order": [1, 2]}) # doctest: +SKIP
+        >>> new_wcs = w.set_inputs(spectral_order=2) # doctest: +SKIP
+        >>> new_wcs.inputs # doctest: +SKIP
+            ("x", "y")
+
+        """
+        if not HAS_FIX_INPUTS:
+            raise ImportError('"fix_inputs" needs astropy version >= 4.0.')
+
+        new_pipeline = []
+        step0 = self.pipeline[0]
+        new_transform = fix_inputs(step0[1], fixed)
+        new_pipeline.append((step0[0], new_transform))
+        new_pipeline.extend(self.pipeline[1:])
+        return self.__class__(new_pipeline)
